if [ ! -e /etc/lighttpd/conf.d/access_log.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/access_log.conf /etc/lighttpd/conf.d/access_log.conf
fi

if [ ! -e /etc/lighttpd/conf.d/auth.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/auth.conf /etc/lighttpd/conf.d/auth.conf
fi

if [ ! -e /etc/lighttpd/conf.d/cgi.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/cgi.conf /etc/lighttpd/conf.d/cgi.conf
fi

if [ ! -e /etc/lighttpd/conf.d/debug.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/debug.conf /etc/lighttpd/conf.d/debug.conf
fi

if [ ! -e /etc/lighttpd/conf.d/deflate.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/deflate.conf /etc/lighttpd/conf.d/deflate.conf
fi

if [ ! -e /etc/lighttpd/conf.d/dirlisting.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/dirlisting.conf /etc/lighttpd/conf.d/dirlisting.conf
fi

if [ ! -e /etc/lighttpd/conf.d/evhost.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/evhost.conf /etc/lighttpd/conf.d/evhost.conf
fi

if [ ! -e /etc/lighttpd/conf.d/expire.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/expire.conf /etc/lighttpd/conf.d/expire.conf
fi

if [ ! -e /etc/lighttpd/conf.d/fastcgi.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/fastcgi.conf /etc/lighttpd/conf.d/fastcgi.conf
fi

if [ ! -e /etc/lighttpd/conf.d/magnet.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/magnet.conf /etc/lighttpd/conf.d/magnet.conf
fi

if [ ! -e /etc/lighttpd/conf.d/mime.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/mime.conf /etc/lighttpd/conf.d/mime.conf
fi

if [ ! -e /etc/lighttpd/conf.d/proxy.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/proxy.conf /etc/lighttpd/conf.d/proxy.conf
fi

if [ ! -e /etc/lighttpd/conf.d/rrdtool.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/rrdtool.conf /etc/lighttpd/conf.d/rrdtool.conf
fi

if [ ! -e /etc/lighttpd/conf.d/scgi.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/scgi.conf /etc/lighttpd/conf.d/scgi.conf
fi

if [ ! -e /etc/lighttpd/conf.d/simple_vhost.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/simple_vhost.conf /etc/lighttpd/conf.d/simple_vhost.conf
fi

if [ ! -e /etc/lighttpd/conf.d/ssi.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/ssi.conf /etc/lighttpd/conf.d/ssi.conf
fi

if [ ! -e /etc/lighttpd/conf.d/status.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/status.conf /etc/lighttpd/conf.d/status.conf
fi

if [ ! -e /etc/lighttpd/conf.d/tls.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/tls.conf /etc/lighttpd/conf.d/tls.conf
fi

if [ ! -e /etc/lighttpd/conf.d/userdir.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/userdir.conf /etc/lighttpd/conf.d/userdir.conf
fi

if [ ! -e /etc/lighttpd/conf.d/webdav.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd/conf.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/conf.d/webdav.conf /etc/lighttpd/conf.d/webdav.conf
fi

if [ ! -e /etc/lighttpd/lighttpd.annotated.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd
    /usr/bin/cp /etc/defaults/etc/lighttpd/lighttpd.annotated.conf /etc/lighttpd/lighttpd.annotated.conf
fi

if [ ! -e /etc/lighttpd/lighttpd.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd
    /usr/bin/cp /etc/defaults/etc/lighttpd/lighttpd.conf /etc/lighttpd/lighttpd.conf
fi

if [ ! -e /etc/lighttpd/modules.conf ]
then
    /usr/bin/mkdir -p /etc/lighttpd
    /usr/bin/cp /etc/defaults/etc/lighttpd/modules.conf /etc/lighttpd/modules.conf
fi

if [ ! -e /etc/lighttpd/vhosts.d/vhosts.template ]
then
    /usr/bin/mkdir -p /etc/lighttpd/vhosts.d
    /usr/bin/cp /etc/defaults/etc/lighttpd/vhosts.d/vhosts.template /etc/lighttpd/vhosts.d/vhosts.template
fi

